@@ -69,6 +69,7 @@
 #define P_D_USERNAME	0x100
 #define P_F_USERSTR	0x200
 #define P_F_PROCSTR	0x400
+#define P_D_UNIT	0x800
 
 #define DISPLAY_PID(m)		(((m) & P_D_PID) == P_D_PID)
 #define DISPLAY_ALL_PID(m)	(((m) & P_D_ALL_PID) == P_D_ALL_PID)
@@ -81,6 +82,7 @@
 #define DISPLAY_USERNAME(m)	(((m) & P_D_USERNAME) == P_D_USERNAME)
 #define USER_STRING(m)		(((m) & P_F_USERSTR) == P_F_USERSTR)
 #define PROCESS_STRING(m)	(((m) & P_F_PROCSTR) == P_F_PROCSTR)
+#define DISPLAY_UNIT(m)		(((m) & P_D_UNIT) == P_D_UNIT)
 
 /* Per-process flags */
 #define F_NO_PID_IO	0x01
