@@ -148,116 +148,117 @@ __print_funct_t print_cpu_stats(struct activity *a, int prev, int curr,
 		 */
 
 		/* Should current CPU (including CPU "all") be displayed? */
-		if (a->bitmap->b_array[i >> 3] & (1 << (i & 0x07))) {
+		if (!(a->bitmap->b_array[i >> 3] & (1 << (i & 0x07))))
+			/* No */
+			continue;
 
-			/* Yes: Display it */
-			printf("%-11s", timestamp[curr]);
+		/* Yes: Display it */
+		printf("%-11s", timestamp[curr]);
 
-			if (!i) {
-				/* This is CPU "all" */
-				cprintf_in(IS_STR, " %s", "    all", 0);
-			}
-			else {
-				cprintf_in(IS_INT, " %7d", "", i - 1);
+		if (!i) {
+			/* This is CPU "all" */
+			cprintf_in(IS_STR, " %s", "    all", 0);
+		}
+		else {
+			cprintf_in(IS_INT, " %7d", "", i - 1);
 
+			/*
+			 * If the CPU is offline then it is omited from /proc/stat:
+			 * All the fields couldn't have been read and the sum of them is zero.
+			 * (Remember that guest/guest_nice times are already included in
+			 * user/nice modes.)
+			 */
+			if ((scc->cpu_user    + scc->cpu_nice + scc->cpu_sys   +
+			     scc->cpu_iowait  + scc->cpu_idle + scc->cpu_steal +
+			     scc->cpu_hardirq + scc->cpu_softirq) == 0) {
 				/*
-				 * If the CPU is offline then it is omited from /proc/stat:
-				 * All the fields couldn't have been read and the sum of them is zero.
-				 * (Remember that guest/guest_nice times are already included in
-				 * user/nice modes.)
+				 * Set current struct fields (which have been set to zero)
+				 * to values from previous iteration. Hence their values won't
+				 * jump from zero when the CPU comes back online.
 				 */
-				if ((scc->cpu_user    + scc->cpu_nice + scc->cpu_sys   +
-				     scc->cpu_iowait  + scc->cpu_idle + scc->cpu_steal +
-				     scc->cpu_hardirq + scc->cpu_softirq) == 0) {
-					/*
-					 * Set current struct fields (which have been set to zero)
-					 * to values from previous iteration. Hence their values won't
-					 * jump from zero when the CPU comes back online.
-					 */
-					*scc = *scp;
+				*scc = *scp;
 
-					/* %user, %nice, %system, %iowait, %steal, ..., %idle */
-					cprintf_pc(6, 9, 2,
-						   0.0, 0.0, 0.0, 0.0, 0.0, 0.0);
+				/* %user, %nice, %system, %iowait, %steal, ..., %idle */
+				cprintf_pc(6, 9, 2,
+					   0.0, 0.0, 0.0, 0.0, 0.0, 0.0);
 
-					if (DISPLAY_CPU_ALL(a->opt_flags)) {
-						/*
-						 * Four additional fields to display:
-						 * %irq, %soft, %guest, %gnice.
-						 */
-						cprintf_pc(4, 9, 2,
-							   0.0, 0.0, 0.0, 0.0);
-					}
-					printf("\n");
-					continue;
-				}
-
-				/* Recalculate interval for current proc */
-				g_itv = get_per_cpu_interval(scc, scp);
-
-				if (!g_itv) {
-					/*
-					 * If the CPU is tickless then there is no change in CPU values
-					 * but the sum of values is not zero.
-					 * %user, %nice, %system, %iowait, %steal, ..., %idle
-					 */
-					cprintf_pc(5, 9, 2,
-						   0.0, 0.0, 0.0, 0.0, 0.0);
-
-					if (DISPLAY_CPU_DEF(a->opt_flags)) {
-						cprintf_pc(1, 9, 2, 100.0);
-						printf("\n");
-					}
+				if (DISPLAY_CPU_ALL(a->opt_flags)) {
 					/*
 					 * Four additional fields to display:
 					 * %irq, %soft, %guest, %gnice.
 					 */
-					else if (DISPLAY_CPU_ALL(a->opt_flags)) {
-						cprintf_pc(4, 9, 2,
-							   0.0, 0.0, 0.0, 100.0);
-						printf("\n");
-					}
-					continue;
+					cprintf_pc(4, 9, 2,
+						   0.0, 0.0, 0.0, 0.0);
 				}
+				printf("\n");
+				continue;
 			}
 
-			if (DISPLAY_CPU_DEF(a->opt_flags)) {
-				cprintf_pc(6, 9, 2,
-					   ll_sp_value(scp->cpu_user, scc->cpu_user, g_itv),
-					   ll_sp_value(scp->cpu_nice, scc->cpu_nice, g_itv),
-					   ll_sp_value(scp->cpu_sys + scp->cpu_hardirq + scp->cpu_softirq,
-						       scc->cpu_sys + scc->cpu_hardirq + scc->cpu_softirq,
-						       g_itv),
-					   ll_sp_value(scp->cpu_iowait, scc->cpu_iowait, g_itv),
-					   ll_sp_value(scp->cpu_steal, scc->cpu_steal, g_itv),
-					   scc->cpu_idle < scp->cpu_idle ?
-					   0.0 :
-					   ll_sp_value(scp->cpu_idle, scc->cpu_idle, g_itv));
-				printf("\n");
-			}
-			else if (DISPLAY_CPU_ALL(a->opt_flags)) {
-				cprintf_pc(10, 9, 2,
-					   (scc->cpu_user - scc->cpu_guest) < (scp->cpu_user - scp->cpu_guest) ?
-					   0.0 :
-					   ll_sp_value(scp->cpu_user - scp->cpu_guest,
-						       scc->cpu_user - scc->cpu_guest, g_itv),
-						       (scc->cpu_nice - scc->cpu_guest_nice) < (scp->cpu_nice - scp->cpu_guest_nice) ?
-					   0.0 :
-					   ll_sp_value(scp->cpu_nice - scp->cpu_guest_nice,
-						       scc->cpu_nice - scc->cpu_guest_nice, g_itv),
-					   ll_sp_value(scp->cpu_sys, scc->cpu_sys, g_itv),
-					   ll_sp_value(scp->cpu_iowait, scc->cpu_iowait, g_itv),
-					   ll_sp_value(scp->cpu_steal, scc->cpu_steal, g_itv),
-					   ll_sp_value(scp->cpu_hardirq, scc->cpu_hardirq, g_itv),
-					   ll_sp_value(scp->cpu_softirq, scc->cpu_softirq, g_itv),
-					   ll_sp_value(scp->cpu_guest, scc->cpu_guest, g_itv),
-					   ll_sp_value(scp->cpu_guest_nice, scc->cpu_guest_nice, g_itv),
-					   scc->cpu_idle < scp->cpu_idle ?
-					   0.0 :
-					   ll_sp_value(scp->cpu_idle, scc->cpu_idle, g_itv));
-				printf("\n");
+			/* Recalculate interval for current proc */
+			g_itv = get_per_cpu_interval(scc, scp);
+
+			if (!g_itv) {
+				/*
+				 * If the CPU is tickless then there is no change in CPU values
+				 * but the sum of values is not zero.
+				 * %user, %nice, %system, %iowait, %steal, ..., %idle
+				 */
+				cprintf_pc(5, 9, 2,
+					   0.0, 0.0, 0.0, 0.0, 0.0);
+
+				if (DISPLAY_CPU_DEF(a->opt_flags)) {
+					cprintf_pc(1, 9, 2, 100.0);
+					printf("\n");
+				}
+				/*
+				 * Four additional fields to display:
+				 * %irq, %soft, %guest, %gnice.
+				 */
+				else if (DISPLAY_CPU_ALL(a->opt_flags)) {
+					cprintf_pc(4, 9, 2,
+						   0.0, 0.0, 0.0, 100.0);
+					printf("\n");
+				}
+				continue;
 			}
 		}
+
+		if (DISPLAY_CPU_DEF(a->opt_flags)) {
+			cprintf_pc(6, 9, 2,
+				   ll_sp_value(scp->cpu_user, scc->cpu_user, g_itv),
+				   ll_sp_value(scp->cpu_nice, scc->cpu_nice, g_itv),
+				   ll_sp_value(scp->cpu_sys + scp->cpu_hardirq + scp->cpu_softirq,
+					       scc->cpu_sys + scc->cpu_hardirq + scc->cpu_softirq,
+					       g_itv),
+				   ll_sp_value(scp->cpu_iowait, scc->cpu_iowait, g_itv),
+				   ll_sp_value(scp->cpu_steal, scc->cpu_steal, g_itv),
+				   scc->cpu_idle < scp->cpu_idle ?
+				   0.0 :
+				   ll_sp_value(scp->cpu_idle, scc->cpu_idle, g_itv));
+			printf("\n");
+		}
+		else if (DISPLAY_CPU_ALL(a->opt_flags)) {
+			cprintf_pc(10, 9, 2,
+				   (scc->cpu_user - scc->cpu_guest) < (scp->cpu_user - scp->cpu_guest) ?
+				   0.0 :
+				   ll_sp_value(scp->cpu_user - scp->cpu_guest,
+					       scc->cpu_user - scc->cpu_guest, g_itv),
+					       (scc->cpu_nice - scc->cpu_guest_nice) < (scp->cpu_nice - scp->cpu_guest_nice) ?
+				   0.0 :
+				   ll_sp_value(scp->cpu_nice - scp->cpu_guest_nice,
+					       scc->cpu_nice - scc->cpu_guest_nice, g_itv),
+				   ll_sp_value(scp->cpu_sys, scc->cpu_sys, g_itv),
+				   ll_sp_value(scp->cpu_iowait, scc->cpu_iowait, g_itv),
+				   ll_sp_value(scp->cpu_steal, scc->cpu_steal, g_itv),
+				   ll_sp_value(scp->cpu_hardirq, scc->cpu_hardirq, g_itv),
+				   ll_sp_value(scp->cpu_softirq, scc->cpu_softirq, g_itv),
+				   ll_sp_value(scp->cpu_guest, scc->cpu_guest, g_itv),
+				   ll_sp_value(scp->cpu_guest_nice, scc->cpu_guest_nice, g_itv),
+				   scc->cpu_idle < scp->cpu_idle ?
+				   0.0 :
+				   ll_sp_value(scp->cpu_idle, scc->cpu_idle, g_itv));
+			printf("\n");
+		}
 	}
 }
 
@@ -284,7 +285,7 @@ __print_funct_t print_pcsw_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(2, 9, 2,
+	cprintf_f(-1, 2, 9, 2,
 		  S_VALUE(spp->processes,      spc->processes,      itv),
 		  S_VALUE(spp->context_switch, spc->context_switch, itv));
 	printf("\n");
@@ -337,7 +338,7 @@ __print_funct_t print_irq_stats(struct activity *a, int prev, int curr,
 				cprintf_in(IS_INT, " %9d", "", i -1);
 			}
 
-			cprintf_f(1, 9, 2, S_VALUE(sip->irq_nr, sic->irq_nr, itv));
+			cprintf_f(-1, 1, 9, 2, S_VALUE(sip->irq_nr, sic->irq_nr, itv));
 			printf("\n");
 		}
 	}
@@ -366,7 +367,7 @@ __print_funct_t print_swap_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(2, 9, 2,
+	cprintf_f(-1, 2, 9, 2,
 		  S_VALUE(ssp->pswpin,  ssc->pswpin,  itv),
 		  S_VALUE(ssp->pswpout, ssc->pswpout, itv));
 	printf("\n");
@@ -395,7 +396,7 @@ __print_funct_t print_paging_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(8, 9, 2,
+	cprintf_f(-1, 8, 9, 2,
 		  S_VALUE(spp->pgpgin,        spc->pgpgin,        itv),
 		  S_VALUE(spp->pgpgout,       spc->pgpgout,       itv),
 		  S_VALUE(spp->pgfault,       spc->pgfault,       itv),
@@ -443,7 +444,7 @@ __print_funct_t print_io_stats(struct activity *a, int prev, int curr,
 	 * We display 0.0 in this case though we should rather tell
 	 * the user that the value cannot be calculated here.
 	 */
-	cprintf_f(5, 9, 2,
+	cprintf_f(-1, 5, 9, 2,
 		  sic->dk_drive < sip->dk_drive ? 0.0 :
 		  S_VALUE(sip->dk_drive, sic->dk_drive, itv),
 		  sic->dk_drive_rio < sip->dk_drive_rio ? 0.0 :
@@ -477,22 +478,29 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 		*smc = (struct stats_memory *) a->buf[curr],
 		*smp = (struct stats_memory *) a->buf[prev];
 	static unsigned long long
-		avg_frmkb    = 0,
-		avg_bufkb    = 0,
-		avg_camkb    = 0,
-		avg_comkb    = 0,
-		avg_activekb = 0,
-		avg_inactkb  = 0,
-		avg_dirtykb  = 0,
-		avg_anonpgkb = 0,
-		avg_slabkb   = 0,
-		avg_kstackkb = 0,
-		avg_pgtblkb  = 0,
-		avg_vmusedkb = 0;
+		avg_frmkb       = 0,
+		avg_bufkb       = 0,
+		avg_camkb       = 0,
+		avg_comkb       = 0,
+		avg_activekb    = 0,
+		avg_inactkb     = 0,
+		avg_dirtykb     = 0,
+		avg_anonpgkb    = 0,
+		avg_slabkb      = 0,
+		avg_kstackkb    = 0,
+		avg_pgtblkb     = 0,
+		avg_vmusedkb    = 0,
+		avg_availablekb = 0;
 	static unsigned long long
 		avg_frskb = 0,
 		avg_tlskb = 0,
 		avg_caskb = 0;
+	int unit = -1;
+
+	if (DISPLAY_UNIT(flags)) {
+		/* Default values unit is kB */
+		unit = 2;
+	}
 
 	if (DISPLAY_MEMORY(a->opt_flags)) {
 		if (dis) {
@@ -500,7 +508,7 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 		}
 
 		printf("%-11s", timestamp[curr]);
-		cprintf_f(3, 9, 2,
+		cprintf_f(-1, 3, 9, 2,
 			  S_VALUE((double) KB_TO_PG(smp->frmkb), (double) KB_TO_PG(smc->frmkb), itv),
 			  S_VALUE((double) KB_TO_PG(smp->bufkb), (double) KB_TO_PG(smc->bufkb), itv),
 			  S_VALUE((double) KB_TO_PG(smp->camkb), (double) KB_TO_PG(smc->camkb), itv));
@@ -515,14 +523,15 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 		if (!dispavg) {
 			/* Display instantaneous values */
 			printf("%-11s", timestamp[curr]);
-			cprintf_u64(2, 9,
+			cprintf_u64(unit, 3, 9,
 				    (unsigned long long) smc->frmkb,
+				    (unsigned long long) smc->availablekb,
 				    (unsigned long long) (smc->tlmkb - smc->frmkb));
 			cprintf_pc(1, 9, 2,
 				   smc->tlmkb ?
 				   SP_VALUE(smc->frmkb, smc->tlmkb, smc->tlmkb)
 				   : 0.0);
-			cprintf_u64(3, 9,
+			cprintf_u64(unit, 3, 9,
 				    (unsigned long long) smc->bufkb,
 				    (unsigned long long) smc->camkb,
 				    (unsigned long long) smc->comkb);
@@ -530,14 +539,14 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 				   (smc->tlmkb + smc->tlskb) ?
 				   SP_VALUE(0, smc->comkb, smc->tlmkb + smc->tlskb)
 				   : 0.0);
-			cprintf_u64(3, 9,
+			cprintf_u64(unit, 3, 9,
 				    (unsigned long long) smc->activekb,
 				    (unsigned long long) smc->inactkb,
 				    (unsigned long long) smc->dirtykb);
 
 			if (DISPLAY_MEM_ALL(a->opt_flags)) {
 				/* Display extended memory statistics */
-				cprintf_u64(5, 9,
+				cprintf_u64(unit, 5, 9,
 					    (unsigned long long) smc->anonpgkb,
 					    (unsigned long long) smc->slabkb,
 					    (unsigned long long) smc->kstackkb,
@@ -552,30 +561,32 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 			 * We assume that the total amount of memory installed can not vary
 			 * during the interval given on the command line.
 			 */
-			avg_frmkb    += smc->frmkb;
-			avg_bufkb    += smc->bufkb;
-			avg_camkb    += smc->camkb;
-			avg_comkb    += smc->comkb;
-			avg_activekb += smc->activekb;
-			avg_inactkb  += smc->inactkb;
-			avg_dirtykb  += smc->dirtykb;
-			avg_anonpgkb += smc->anonpgkb;
-			avg_slabkb   += smc->slabkb;
-			avg_kstackkb += smc->kstackkb;
-			avg_pgtblkb  += smc->pgtblkb;
-			avg_vmusedkb += smc->vmusedkb;
+			avg_frmkb       += smc->frmkb;
+			avg_bufkb       += smc->bufkb;
+			avg_camkb       += smc->camkb;
+			avg_comkb       += smc->comkb;
+			avg_activekb    += smc->activekb;
+			avg_inactkb     += smc->inactkb;
+			avg_dirtykb     += smc->dirtykb;
+			avg_anonpgkb    += smc->anonpgkb;
+			avg_slabkb      += smc->slabkb;
+			avg_kstackkb    += smc->kstackkb;
+			avg_pgtblkb     += smc->pgtblkb;
+			avg_vmusedkb    += smc->vmusedkb;
+			avg_availablekb += smc->availablekb;
 		}
 		else {
 			/* Display average values */
 			printf("%-11s", timestamp[curr]);
-			cprintf_f(2, 9, 0,
+			cprintf_f(unit, 3, 9, 0,
 				  (double) avg_frmkb / avg_count,
+				  (double) avg_availablekb / avg_count,
 				  (double) smc->tlmkb - ((double) avg_frmkb / avg_count));
 			cprintf_pc(1, 9, 2,
 				   smc->tlmkb ?
 				   SP_VALUE((double) (avg_frmkb / avg_count), smc->tlmkb, smc->tlmkb)
 				   : 0.0);
-			cprintf_f(3, 9, 0,
+			cprintf_f(unit, 3, 9, 0,
 				  (double) avg_bufkb / avg_count,
 				  (double) avg_camkb / avg_count,
 				  (double) avg_comkb / avg_count);
@@ -583,13 +594,13 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 				   (smc->tlmkb + smc->tlskb) ?
 				   SP_VALUE(0.0, (double) (avg_comkb / avg_count), smc->tlmkb + smc->tlskb)
 				   : 0.0);
-			cprintf_f(3, 9, 0,
+			cprintf_f(unit, 3, 9, 0,
 				  (double) avg_activekb / avg_count,
 				  (double) avg_inactkb / avg_count,
 				  (double) avg_dirtykb / avg_count);
 
 			if (DISPLAY_MEM_ALL(a->opt_flags)) {
-				cprintf_f(5, 9, 0,
+				cprintf_f(unit, 5, 9, 0,
 					  (double) avg_anonpgkb / avg_count,
 					  (double) avg_slabkb / avg_count,
 					  (double) avg_kstackkb / avg_count,
@@ -603,7 +614,7 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 			avg_frmkb = avg_bufkb = avg_camkb = avg_comkb = 0;
 			avg_activekb = avg_inactkb = avg_dirtykb = 0;
 			avg_anonpgkb = avg_slabkb = avg_kstackkb = 0;
-			avg_pgtblkb = avg_vmusedkb = 0;
+			avg_pgtblkb = avg_vmusedkb = avg_availablekb = 0;
 		}
 	}
 
@@ -615,14 +626,14 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 		if (!dispavg) {
 			/* Display instantaneous values */
 			printf("%-11s", timestamp[curr]);
-			cprintf_u64(2, 9,
+			cprintf_u64(unit, 2, 9,
 				    (unsigned long long) smc->frskb,
 				    (unsigned long long) (smc->tlskb - smc->frskb));
 			cprintf_pc(1, 9, 2,
 				   smc->tlskb ?
 				   SP_VALUE(smc->frskb, smc->tlskb, smc->tlskb)
 				   : 0.0);
-			cprintf_u64(1, 9,
+			cprintf_u64(unit, 1, 9,
 				    (unsigned long long) smc->caskb);
 			cprintf_pc(1, 9, 2,
 				   (smc->tlskb - smc->frskb) ?
@@ -642,7 +653,7 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 		else {
 			/* Display average values */
 			printf("%-11s", timestamp[curr]);
-			cprintf_f(2, 9, 0,
+			cprintf_f(unit, 2, 9, 0,
 				  (double) avg_frskb / avg_count,
 				  ((double) avg_tlskb / avg_count) -
 				  ((double) avg_frskb / avg_count));
@@ -652,7 +663,7 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 					    (double) avg_tlskb / avg_count,
 					    (double) avg_tlskb / avg_count)
 				   : 0.0);
-			cprintf_f(1, 9, 0,
+			cprintf_f(unit, 1, 9, 0,
 				  (double) avg_caskb / avg_count);
 			cprintf_pc(1, 9, 2,
 				   (avg_tlskb != avg_frskb) ?
@@ -731,7 +742,7 @@ void stub_print_ktables_stats(struct activity *a, int curr, int dispavg)
 	if (!dispavg) {
 		/* Display instantaneous values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_u64(4, 9,
+		cprintf_u64(-1, 4, 9,
 			    (unsigned long long) skc->dentry_stat,
 			    (unsigned long long) skc->file_used,
 			    (unsigned long long) skc->inode_used,
@@ -750,7 +761,7 @@ void stub_print_ktables_stats(struct activity *a, int curr, int dispavg)
 	else {
 		/* Display average values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_f(4, 9, 0,
+		cprintf_f(-1, 4, 9, 0,
 			  (double) avg_dentry_stat / avg_count,
 			  (double) avg_file_used   / avg_count,
 			  (double) avg_inode_used  / avg_count,
@@ -826,14 +837,14 @@ void stub_print_queue_stats(struct activity *a, int curr, int dispavg)
 	if (!dispavg) {
 		/* Display instantaneous values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_u64(2, 9,
+		cprintf_u64(-1, 2, 9,
 			    (unsigned long long) sqc->nr_running,
 			    (unsigned long long) sqc->nr_threads);
-		cprintf_f(3, 9, 2,
+		cprintf_f(-1, 3, 9, 2,
 			  (double) sqc->load_avg_1  / 100,
 			  (double) sqc->load_avg_5  / 100,
 			  (double) sqc->load_avg_15 / 100);
-		cprintf_u64(1, 9,
+		cprintf_u64(-1, 1, 9,
 			    (unsigned long long) sqc->procs_blocked);
 		printf("\n");
 
@@ -848,14 +859,14 @@ void stub_print_queue_stats(struct activity *a, int curr, int dispavg)
 	else {
 		/* Display average values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_f(2, 9, 0,
+		cprintf_f(-1, 2, 9, 0,
 			  (double) avg_nr_running / avg_count,
 			  (double) avg_nr_threads / avg_count);
-		cprintf_f(3, 9, 2,
+		cprintf_f(-1, 3, 9, 2,
 			  (double) avg_load_avg_1  / (avg_count * 100),
 			  (double) avg_load_avg_5  / (avg_count * 100),
 			  (double) avg_load_avg_15 / (avg_count * 100));
-		cprintf_f(1, 9, 0,
+		cprintf_f(-1, 1, 9, 0,
 			  (double) avg_procs_blocked / avg_count);
 		printf("\n");
 
@@ -933,7 +944,7 @@ __print_funct_t print_serial_stats(struct activity *a, int prev, int curr,
 		cprintf_in(IS_INT, "       %3d", "", ssc->line - 1);
 
 		if ((ssc->line == ssp->line) || WANT_SINCE_BOOT(flags)) {
-			cprintf_f(6, 9, 2,
+			cprintf_f(-1, 6, 9, 2,
 				  S_VALUE(ssp->rx,      ssc->rx,      itv),
 				  S_VALUE(ssp->tx,      ssc->tx,      itv),
 				  S_VALUE(ssp->frame,   ssc->frame,   itv),
@@ -967,6 +978,12 @@ __print_funct_t print_disk_stats(struct activity *a, int prev, int curr,
 	struct stats_disk *sdc,	*sdp;
 	struct ext_disk_stats xds;
 	char *dev_name, *persist_dev_name;
+	int unit = -1;
+
+	if (DISPLAY_UNIT(flags)) {
+		/* Default values unit is sectors */
+		unit = 0;
+	}
 
 	if (dis) {
 		print_hdr_line(timestamp[!curr], a, FIRST, 0, 9);
@@ -1009,10 +1026,12 @@ __print_funct_t print_disk_stats(struct activity *a, int prev, int curr,
 		printf("%-11s", timestamp[curr]);
 
 		cprintf_in(IS_STR, " %9s", dev_name, 0);
-		cprintf_f(7, 9, 2,
-			  S_VALUE(sdp->nr_ios, sdc->nr_ios,  itv),
+		cprintf_f(-1, 1, 9, 2,
+			  S_VALUE(sdp->nr_ios, sdc->nr_ios,  itv));
+		cprintf_f(unit, 2, 9, 2,
 			  S_VALUE(sdp->rd_sect, sdc->rd_sect, itv),
-			  S_VALUE(sdp->wr_sect, sdc->wr_sect, itv),
+			  S_VALUE(sdp->wr_sect, sdc->wr_sect, itv));
+		cprintf_f(-1, 4, 9, 2,
 			  /* See iostat for explanations */
 			  xds.arqsz,
 			  S_VALUE(sdp->rq_ticks, sdc->rq_ticks, itv) / 1000.0,
@@ -1041,6 +1060,12 @@ __print_funct_t print_net_dev_stats(struct activity *a, int prev, int curr,
 	int i, j;
 	struct stats_net_dev *sndc, *sndp;
 	double rxkb, txkb, ifutil;
+	int unit = -1;
+
+	if (DISPLAY_UNIT(flags)) {
+		/* Default values unit is bytes */
+		unit = 1;
+	}
 
 	if (dis) {
 		print_hdr_line(timestamp[!curr], a, FIRST, 0, 9);
@@ -1062,11 +1087,13 @@ __print_funct_t print_net_dev_stats(struct activity *a, int prev, int curr,
 		rxkb = S_VALUE(sndp->rx_bytes, sndc->rx_bytes, itv);
 		txkb = S_VALUE(sndp->tx_bytes, sndc->tx_bytes, itv);
 
-		cprintf_f(7, 9, 2,
+		cprintf_f(-1, 2, 9, 2,
 			  S_VALUE(sndp->rx_packets,    sndc->rx_packets,    itv),
-			  S_VALUE(sndp->tx_packets,    sndc->tx_packets,    itv),
-			  rxkb / 1024,
-			  txkb / 1024,
+			  S_VALUE(sndp->tx_packets,    sndc->tx_packets,    itv));
+		cprintf_f(unit, 2, 9, 2,
+			  unit < 0 ? rxkb / 1024 : rxkb,
+			  unit < 0 ? txkb / 1024 : txkb);
+		cprintf_f(-1, 3, 9, 2,
 			  S_VALUE(sndp->rx_compressed, sndc->rx_compressed, itv),
 			  S_VALUE(sndp->tx_compressed, sndc->tx_compressed, itv),
 			  S_VALUE(sndp->multicast,     sndc->multicast,     itv));
@@ -1110,7 +1137,7 @@ __print_funct_t print_net_edev_stats(struct activity *a, int prev, int curr,
 		printf("%-11s", timestamp[curr]);
 		cprintf_in(IS_STR, " %9s", snedc->interface, 0);
 
-		cprintf_f(9, 9, 2,
+		cprintf_f(-1, 9, 9, 2,
 			  S_VALUE(snedp->rx_errors,         snedc->rx_errors,         itv),
 			  S_VALUE(snedp->tx_errors,         snedc->tx_errors,         itv),
 			  S_VALUE(snedp->collisions,        snedc->collisions,        itv),
@@ -1147,7 +1174,7 @@ __print_funct_t print_net_nfs_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(6, 9, 2,
+	cprintf_f(-1, 6, 9, 2,
 		  S_VALUE(snnp->nfs_rpccnt,     snnc->nfs_rpccnt,     itv),
 		  S_VALUE(snnp->nfs_rpcretrans, snnc->nfs_rpcretrans, itv),
 		  S_VALUE(snnp->nfs_readcnt,    snnc->nfs_readcnt,    itv),
@@ -1180,7 +1207,7 @@ __print_funct_t print_net_nfsd_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(11, 9, 2,
+	cprintf_f(-1, 11, 9, 2,
 		  S_VALUE(snndp->nfsd_rpccnt,    snndc->nfsd_rpccnt,    itv),
 		  S_VALUE(snndp->nfsd_rpcbad,    snndc->nfsd_rpcbad,    itv),
 		  S_VALUE(snndp->nfsd_netcnt,    snndc->nfsd_netcnt,    itv),
@@ -1225,7 +1252,7 @@ void stub_print_net_sock_stats(struct activity *a, int curr, int dispavg)
 	if (!dispavg) {
 		/* Display instantaneous values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_u64(6, 9,
+		cprintf_u64(-1, 6, 9,
 			    (unsigned long long) snsc->sock_inuse,
 			    (unsigned long long) snsc->tcp_inuse,
 			    (unsigned long long) snsc->udp_inuse,
@@ -1245,7 +1272,7 @@ void stub_print_net_sock_stats(struct activity *a, int curr, int dispavg)
 	else {
 		/* Display average values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_f(6, 9, 0,
+		cprintf_f(-1, 6, 9, 0,
 			  (double) avg_sock_inuse / avg_count,
 			  (double) avg_tcp_inuse  / avg_count,
 			  (double) avg_udp_inuse  / avg_count,
@@ -1317,7 +1344,7 @@ __print_funct_t print_net_ip_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(8, 9, 2,
+	cprintf_f(-1, 8, 9, 2,
 		  S_VALUE(snip->InReceives,    snic->InReceives,    itv),
 		  S_VALUE(snip->ForwDatagrams, snic->ForwDatagrams, itv),
 		  S_VALUE(snip->InDelivers,    snic->InDelivers,    itv),
@@ -1352,7 +1379,7 @@ __print_funct_t print_net_eip_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(8, 9, 2,
+	cprintf_f(-1, 8, 9, 2,
 		  S_VALUE(sneip->InHdrErrors,     sneic->InHdrErrors,     itv),
 		  S_VALUE(sneip->InAddrErrors,    sneic->InAddrErrors,    itv),
 		  S_VALUE(sneip->InUnknownProtos, sneic->InUnknownProtos, itv),
@@ -1387,7 +1414,7 @@ __print_funct_t print_net_icmp_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(14, 9, 2,
+	cprintf_f(-1, 14, 9, 2,
 		  S_VALUE(snip->InMsgs,           snic->InMsgs,           itv),
 		  S_VALUE(snip->OutMsgs,          snic->OutMsgs,          itv),
 		  S_VALUE(snip->InEchos,          snic->InEchos,          itv),
@@ -1428,7 +1455,7 @@ __print_funct_t print_net_eicmp_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(12, 9, 2,
+	cprintf_f(-1, 12, 9, 2,
 		  S_VALUE(sneip->InErrors,        sneic->InErrors,        itv),
 		  S_VALUE(sneip->OutErrors,       sneic->OutErrors,       itv),
 		  S_VALUE(sneip->InDestUnreachs,  sneic->InDestUnreachs,  itv),
@@ -1467,7 +1494,7 @@ __print_funct_t print_net_tcp_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(4, 9, 2,
+	cprintf_f(-1, 4, 9, 2,
 		  S_VALUE(sntp->ActiveOpens,  sntc->ActiveOpens,  itv),
 		  S_VALUE(sntp->PassiveOpens, sntc->PassiveOpens, itv),
 		  S_VALUE(sntp->InSegs,       sntc->InSegs,       itv),
@@ -1498,7 +1525,7 @@ __print_funct_t print_net_etcp_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(5, 9, 2,
+	cprintf_f(-1, 5, 9, 2,
 		  S_VALUE(snetp->AttemptFails, snetc->AttemptFails, itv),
 		  S_VALUE(snetp->EstabResets,  snetc->EstabResets,  itv),
 		  S_VALUE(snetp->RetransSegs,  snetc->RetransSegs,  itv),
@@ -1530,7 +1557,7 @@ __print_funct_t print_net_udp_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(4, 9, 2,
+	cprintf_f(-1, 4, 9, 2,
 		  S_VALUE(snup->InDatagrams,  snuc->InDatagrams,  itv),
 		  S_VALUE(snup->OutDatagrams, snuc->OutDatagrams, itv),
 		  S_VALUE(snup->NoPorts,      snuc->NoPorts,      itv),
@@ -1566,7 +1593,7 @@ void stub_print_net_sock6_stats(struct activity *a, int curr, int dispavg)
 	if (!dispavg) {
 		/* Display instantaneous values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_u64(4, 9,
+		cprintf_u64(-1, 4, 9,
 			    (unsigned long long) snsc->tcp6_inuse,
 			    (unsigned long long) snsc->udp6_inuse,
 			    (unsigned long long) snsc->raw6_inuse,
@@ -1582,7 +1609,7 @@ void stub_print_net_sock6_stats(struct activity *a, int curr, int dispavg)
 	else {
 		/* Display average values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_f(4, 9, 0,
+		cprintf_f(-1, 4, 9, 0,
 			  (double) avg_tcp6_inuse  / avg_count,
 			  (double) avg_udp6_inuse  / avg_count,
 			  (double) avg_raw6_inuse  / avg_count,
@@ -1651,7 +1678,7 @@ __print_funct_t print_net_ip6_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(10, 9, 2,
+	cprintf_f(-1, 10, 9, 2,
 		  S_VALUE(snip->InReceives6,       snic->InReceives6,       itv),
 		  S_VALUE(snip->OutForwDatagrams6, snic->OutForwDatagrams6, itv),
 		  S_VALUE(snip->InDelivers6,       snic->InDelivers6,       itv),
@@ -1688,7 +1715,7 @@ __print_funct_t print_net_eip6_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(11, 9, 2,
+	cprintf_f(-1, 11, 9, 2,
 		  S_VALUE(sneip->InHdrErrors6,     sneic->InHdrErrors6,     itv),
 		  S_VALUE(sneip->InAddrErrors6,    sneic->InAddrErrors6,    itv),
 		  S_VALUE(sneip->InUnknownProtos6, sneic->InUnknownProtos6, itv),
@@ -1726,7 +1753,7 @@ __print_funct_t print_net_icmp6_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(17, 9, 2,
+	cprintf_f(-1, 17, 9, 2,
 		  S_VALUE(snip->InMsgs6,                    snic->InMsgs6,                    itv),
 		  S_VALUE(snip->OutMsgs6,                   snic->OutMsgs6,                   itv),
 		  S_VALUE(snip->InEchos6,                   snic->InEchos6,                   itv),
@@ -1770,7 +1797,7 @@ __print_funct_t print_net_eicmp6_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(11, 9, 2,
+	cprintf_f(-1, 11, 9, 2,
 		  S_VALUE(sneip->InErrors6,        sneic->InErrors6,        itv),
 		  S_VALUE(sneip->InDestUnreachs6,  sneic->InDestUnreachs6,  itv),
 		  S_VALUE(sneip->OutDestUnreachs6, sneic->OutDestUnreachs6, itv),
@@ -1808,7 +1835,7 @@ __print_funct_t print_net_udp6_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(4, 9, 2,
+	cprintf_f(-1, 4, 9, 2,
 		  S_VALUE(snup->InDatagrams6,  snuc->InDatagrams6,  itv),
 		  S_VALUE(snup->OutDatagrams6, snuc->OutDatagrams6, itv),
 		  S_VALUE(snup->NoPorts6,      snuc->NoPorts6,      itv),
@@ -1882,7 +1909,7 @@ void stub_print_pwr_cpufreq_stats(struct activity *a, int curr, int dispavg)
 
 			if (!dispavg) {
 				/* Display instantaneous values */
-				cprintf_f(1, 9, 2,
+				cprintf_f(-1, 1, 9, 2,
 					  ((double) spc->cpufreq) / 100);
 				printf("\n");
 				/*
@@ -1893,7 +1920,7 @@ void stub_print_pwr_cpufreq_stats(struct activity *a, int curr, int dispavg)
 			}
 			else {
 				/* Display average values */
-				cprintf_f(1, 9, 2,
+				cprintf_f(-1, 1, 9, 2,
 					  (double) avg_cpufreq[i] / (100 * avg_count));
 				printf("\n");
 			}
@@ -1989,13 +2016,13 @@ void stub_print_pwr_fan_stats(struct activity *a, int curr, int dispavg)
 
 		if (dispavg) {
 			/* Display average values */
-			cprintf_f(2, 9, 2,
+			cprintf_f(-1, 2, 9, 2,
 				  (double) avg_fan[i] / avg_count,
 				  (double) (avg_fan[i] - avg_fan_min[i]) / avg_count);
 		}
 		else {
 			/* Display instantaneous values */
-			cprintf_f(2, 9, 2,
+			cprintf_f(-1, 2, 9, 2,
 				  spc->rpm,
 				  spc->rpm - spc->rpm_min);
 			avg_fan[i]     += spc->rpm;
@@ -2104,7 +2131,7 @@ void stub_print_pwr_temp_stats(struct activity *a, int curr, int dispavg)
 
 		if (dispavg) {
 			/* Display average values */
-			cprintf_f(1, 9, 2, (double) avg_temp[i] / avg_count);
+			cprintf_f(-1, 1, 9, 2, (double) avg_temp[i] / avg_count);
 			cprintf_pc(1, 9, 2,
 				   (avg_temp_max[i] - avg_temp_min[i]) ?
 				   ((double) (avg_temp[i] / avg_count) - avg_temp_min[i]) / (avg_temp_max[i] - avg_temp_min[i]) * 100
@@ -2112,7 +2139,7 @@ void stub_print_pwr_temp_stats(struct activity *a, int curr, int dispavg)
 		}
 		else {
 			/* Display instantaneous values */
-			cprintf_f(1, 9, 2, spc->temp);
+			cprintf_f(-1, 1, 9, 2, spc->temp);
 			cprintf_pc(1, 9, 2,
 				   (spc->temp_max - spc->temp_min) ?
 				   (spc->temp - spc->temp_min) / (spc->temp_max - spc->temp_min) * 100
@@ -2229,7 +2256,7 @@ void stub_print_pwr_in_stats(struct activity *a, int curr, int dispavg)
 
 		if (dispavg) {
 			/* Display average values */
-			cprintf_f(1, 9, 2, (double) avg_in[i] / avg_count);
+			cprintf_f(-1, 1, 9, 2, (double) avg_in[i] / avg_count);
 			cprintf_pc(1, 9, 2,
 				   (avg_in_max[i] - avg_in_min[i]) ?
 				   ((double) (avg_in[i] / avg_count) - avg_in_min[i]) / (avg_in_max[i] - avg_in_min[i]) * 100
@@ -2237,7 +2264,7 @@ void stub_print_pwr_in_stats(struct activity *a, int curr, int dispavg)
 		}
 		else {
 			/* Display instantaneous values */
-			cprintf_f(1, 9, 2, spc->in);
+			cprintf_f(-1, 1, 9, 2, spc->in);
 			cprintf_pc(1, 9, 2,
 				   (spc->in_max - spc->in_min) ?
 				   (spc->in - spc->in_min) / (spc->in_max - spc->in_min) * 100
@@ -2319,6 +2346,12 @@ void stub_print_huge_stats(struct activity *a, int curr, int dispavg)
 	static unsigned long long
 		avg_frhkb = 0,
 		avg_tlhkb = 0;
+	int unit = -1;
+
+	if (DISPLAY_UNIT(flags)) {
+		/* Default values unit is kB */
+		unit = 2;
+	}
 
 	if (dis) {
 		print_hdr_line(timestamp[!curr], a, FIRST, 0, 9);
@@ -2327,7 +2360,7 @@ void stub_print_huge_stats(struct activity *a, int curr, int dispavg)
 	if (!dispavg) {
 		/* Display instantaneous values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_u64(2, 9,
+		cprintf_u64(unit, 2, 9,
 			    (unsigned long long) smc->frhkb,
 			    (unsigned long long) (smc->tlhkb - smc->frhkb));
 		cprintf_pc(1, 9, 2,
@@ -2342,7 +2375,7 @@ void stub_print_huge_stats(struct activity *a, int curr, int dispavg)
 	else {
 		/* Display average values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_f(2, 9, 0,
+		cprintf_f(unit, 2, 9, 0,
 			  (double) avg_frhkb / avg_count,
 			  ((double) avg_tlhkb / avg_count) -
 			  ((double) avg_frhkb / avg_count));
@@ -2464,7 +2497,7 @@ void print_pwr_wghfreq_stats(struct activity *a, int prev, int curr,
 			}
 
 			/* Display weighted frequency for current CPU */
-			cprintf_f(1, 9, 2,
+			cprintf_f(-1, 1, 9, 2,
 				  tis ? ((double) tisfreq) / tis : 0.0);
 			printf("\n");
 		}
@@ -2507,7 +2540,7 @@ void stub_print_pwr_usb_stats(struct activity *a, int curr, int dispavg)
 		cprintf_x(2, 9,
 			  suc->vendor_id,
 			  suc->product_id);
-		cprintf_u64(1, 9,
+		cprintf_u64(-1, 1, 9,
 			    /* bMaxPower is expressed in 2 mA units */
 			    (unsigned long long) (suc->bmaxpower << 1));
 
@@ -2601,6 +2634,12 @@ __print_funct_t stub_print_filesystem_stats(struct activity *a, int curr, int di
 {
 	int i, j;
 	struct stats_filesystem *sfc, *sfm;
+	int unit = -1;
+
+	if (DISPLAY_UNIT(flags)) {
+		/* Default values unit is B */
+		unit = 1;
+	}
 
 	if (dis) {
 		print_hdr_line((dispavg ? _("Summary:") : timestamp[!curr]),
@@ -2615,16 +2654,17 @@ __print_funct_t stub_print_filesystem_stats(struct activity *a, int curr, int di
 			break;
 
 		printf("%-11s", (dispavg ? _("Summary:") : timestamp[curr]));
-		cprintf_f(2, 9, 0,
-			  (double) sfc->f_bfree / 1024 / 1024,
-			  (double) (sfc->f_blocks - sfc->f_bfree) / 1024 / 1024);
+		cprintf_f(unit, 2, 9, 0,
+			  unit < 0 ? (double) sfc->f_bfree / 1024 / 1024 : (double) sfc->f_bfree,
+			  unit < 0 ? (double) (sfc->f_blocks - sfc->f_bfree) / 1024 / 1024 :
+				     (double) (sfc->f_blocks - sfc->f_bfree));
 		cprintf_pc(2, 9, 2,
 			   /* f_blocks is not zero. But test it anyway ;-) */
 			   sfc->f_blocks ? SP_VALUE(sfc->f_bfree, sfc->f_blocks, sfc->f_blocks)
 			   : 0.0,
 			   sfc->f_blocks ? SP_VALUE(sfc->f_bavail, sfc->f_blocks, sfc->f_blocks)
 			   : 0.0);
-		cprintf_u64(2, 9,
+		cprintf_u64(-1, 2, 9,
 			    (unsigned long long) sfc->f_ffree,
 			    (unsigned long long) (sfc->f_files - sfc->f_ffree));
 		cprintf_pc(1, 9, 2,
@@ -2717,7 +2757,7 @@ __print_funct_t print_fchost_stats(struct activity *a, int prev, int curr,
 			break;
 
 		printf("%-11s", timestamp[curr]);
-		cprintf_f(4, 9, 2,
+		cprintf_f(-1, 4, 9, 2,
 			  S_VALUE(sfcp->f_rxframes, sfcc->f_rxframes, itv),
 			  S_VALUE(sfcp->f_txframes, sfcc->f_txframes, itv),
 			  S_VALUE(sfcp->f_rxwords,  sfcc->f_rxwords,  itv),
@@ -2782,7 +2822,7 @@ __print_funct_t print_softnet_stats(struct activity *a, int prev, int curr,
 				cprintf_in(IS_INT, " %7d", "", i - 1);
 			}
 
-			cprintf_f(5, 9, 2,
+			cprintf_f(-1, 5, 9, 2,
 				  S_VALUE(ssnp->processed,    ssnc->processed,    itv),
 				  S_VALUE(ssnp->dropped,      ssnc->dropped,      itv),
 				  S_VALUE(ssnp->time_squeeze, ssnc->time_squeeze, itv),
