@@ -777,6 +777,10 @@ __print_funct_t render_memory_stats(struct activity *a, int isdb, char *pre,
 		       "-\tkbmemfree", NULL, NULL,
 		       smc->frmkb, DNOVAL, NULL);
 
+		render(isdb, pre, PT_USEINT,
+		       "-\tkbavail", NULL, NULL,
+		       smc->availablekb, DNOVAL, NULL);
+
 		render(isdb, pre, PT_USEINT,
 		       "-\tkbmemused", NULL, NULL,
 		       smc->tlmkb - smc->frmkb, DNOVAL, NULL);
