@@ -49,27 +49,6 @@
 int default_file_used = FALSE;
 extern struct act_bitmap cpu_bitmap;
 
-/*
- ***************************************************************************
- * Init a bitmap (CPU, IRQ, etc.).
- *
- * IN:
- * @value	Value used to init bitmap.
- * @sz		Size of the bitmap in bytes.
- *
- * OUT:
- * @bitmap	Bitmap initialized.
- ***************************************************************************
- */
-void set_bitmap(unsigned char bitmap[], unsigned char value, unsigned int sz)
-{
-	register int i;
-
-	for (i = 0; i < sz; i++) {
-		bitmap[i] = value;
-	}
-}
-
 /*
  ***************************************************************************
  * Allocate structures.
@@ -1582,7 +1561,7 @@ int parse_sar_opt(char *argv[], int *opt, struct activity *act[],
 			select_all_activities(act);
 
 			/*
-			 * Force '-P ALL -I XALL -r ALL -u ALL -F'.
+			 * Force '-P ALL -I ALL -r ALL -u ALL -F'.
 			 * Setting -F is compulsory because corresponding activity
 			 * has AO_MULTIPLE_OUTPUTS flag set.
 			 */
@@ -1591,12 +1570,11 @@ int parse_sar_opt(char *argv[], int *opt, struct activity *act[],
 					     AO_F_MEM_SWAP + AO_F_MEM_ALL;
 
 			p = get_activity_position(act, A_IRQ, EXIT_IF_NOT_FOUND);
-			set_bitmap(act[p]->bitmap->b_array, ~0,
-				   BITMAP_SIZE(act[p]->bitmap->b_size));
-
+			memset(act[p]->bitmap->b_array, ~0,
+			       BITMAP_SIZE(act[p]->bitmap->b_size));
 			p = get_activity_position(act, A_CPU, EXIT_IF_NOT_FOUND);
-			set_bitmap(act[p]->bitmap->b_array, ~0,
-				   BITMAP_SIZE(act[p]->bitmap->b_size));
+			memset(act[p]->bitmap->b_array, ~0,
+			       BITMAP_SIZE(act[p]->bitmap->b_size));
 			act[p]->opt_flags = AO_F_CPU_ALL;
 
 			p = get_activity_position(act, A_FILESYSTEM, EXIT_IF_NOT_FOUND);
@@ -1929,45 +1907,21 @@ int parse_sar_n_opt(char *argv[], int *opt, struct activity *act[])
  */
 int parse_sar_I_opt(char *argv[], int *opt, struct activity *act[])
 {
-	int i, p;
-	unsigned char c;
-	char *t;
+	int p;
 
 	/* Select interrupt activity */
 	p = get_activity_position(act, A_IRQ, EXIT_IF_NOT_FOUND);
 	act[p]->options |= AO_SELECTED;
 
-	for (t = strtok(argv[*opt], ","); t; t = strtok(NULL, ",")) {
-		if (!strcmp(t, K_SUM)) {
-			/* Select total number of interrupts */
-			act[p]->bitmap->b_array[0] |= 0x01;
-		}
-		else if (!strcmp(t, K_ALL)) {
-			/* Set bit for the first 16 individual interrupts */
-			act[p]->bitmap->b_array[0] |= 0xfe;
-			act[p]->bitmap->b_array[1] |= 0xff;
-			act[p]->bitmap->b_array[2] |= 0x01;
-		}
-		else if (!strcmp(t, K_XALL)) {
-			/* Set every bit except for total number of interrupts */
-			c = act[p]->bitmap->b_array[0];
-			set_bitmap(act[p]->bitmap->b_array, ~0,
-				   BITMAP_SIZE(act[p]->bitmap->b_size));
-			act[p]->bitmap->b_array[0] = 0xfe | c;
-		}
-		else {
-			/* Get irq number */
-			if (strspn(t, DIGITS) != strlen(t))
-				return 1;
-			i = atoi(t);
-			if ((i < 0) || (i >= act[p]->bitmap->b_size))
-				return 1;
-			act[p]->bitmap->b_array[(i + 1) >> 3] |= 1 << ((i + 1) & 0x07);
-		}
+	if (argv[++(*opt)]) {
+		if (parse_values(argv[*opt], act[p]->bitmap->b_array,
+			     act[p]->bitmap->b_size, K_SUM))
+			return 1;
+		(*opt)++;
+		return 0;
 	}
 
-	(*opt)++;
-	return 0;
+	return 1;
 }
 
 /*
@@ -1989,39 +1943,19 @@ int parse_sar_I_opt(char *argv[], int *opt, struct activity *act[])
  */
 int parse_sa_P_opt(char *argv[], int *opt, unsigned int *flags, struct activity *act[])
 {
-	int i, p;
-	char *t;
+	int p;
 
 	p = get_activity_position(act, A_CPU, EXIT_IF_NOT_FOUND);
 
 	if (argv[++(*opt)]) {
-
-		for (t = strtok(argv[*opt], ","); t; t = strtok(NULL, ",")) {
-			if (!strcmp(t, K_ALL)) {
-				/*
-				 * Set bit for every processor.
-				 * We still don't know if we are going to read stats
-				 * from a file or not...
-				 */
-				set_bitmap(act[p]->bitmap->b_array, ~0,
-					   BITMAP_SIZE(act[p]->bitmap->b_size));
-			}
-			else {
-				/* Get cpu number */
-				if (strspn(t, DIGITS) != strlen(t))
-					return 1;
-				i = atoi(t);
-				if ((i < 0) || (i >= act[p]->bitmap->b_size))
-					return 1;
-				act[p]->bitmap->b_array[(i + 1) >> 3] |= 1 << ((i + 1) & 0x07);
-			}
-		}
+		if (parse_values(argv[*opt], act[p]->bitmap->b_array,
+			     act[p]->bitmap->b_size, K_LOWERALL))
+			return 1;
 		(*opt)++;
+		return 0;
 	}
-	else
-		return 1;
 
-	return 0;
+	return 1;
 }
 
 /*
