@@ -111,8 +111,8 @@ void usage(char *progname)
 	fprintf(stderr, _("Options are:\n"
 			  "[ -A ] [ -B ] [ -b ] [ -C ] [ -D ] [ -d ] [ -F [ MOUNT ] ] [ -H ] [ -h ]\n"
 			  "[ -p ] [ -q ] [ -R ] [ -r [ ALL ] ] [ -S ] [ -t ] [ -u [ ALL ] ] [ -V ]\n"
-			  "[ -v ] [ -W ] [ -w ] [ -y ] [ --sadc ]\n"
-			  "[ -I { <int> [,...] | SUM | ALL | XALL } ] [ -P { <cpu> [,...] | ALL } ]\n"
+			  "[ -v ] [ -W ] [ -w ] [ -y ] [ --human ] [ --sadc ]\n"
+			  "[ -I { <int_list> | SUM | ALL } ] [ -P { <cpu_list> | ALL } ]\n"
 			  "[ -m { <keyword> [,...] | ALL } ] [ -n { <keyword> [,...] | ALL } ]\n"
 			  "[ -j { ID | LABEL | PATH | UUID | ... } ]\n"
 			  "[ -f [ <filename> ] | -o [ <filename> ] | -[0-9]+ ]\n"
@@ -138,7 +138,7 @@ void display_help(char *progname)
 	printf(_("\t-F [ MOUNT ]\n"));
 	printf(_("\t\tFilesystems statistics\n"));
 	printf(_("\t-H\tHugepages utilization statistics\n"));
-	printf(_("\t-I { <int> | SUM | ALL | XALL }\n"
+	printf(_("\t-I { <int_list> | SUM | ALL }\n"
 		 "\t\tInterrupts statistics\n"));
 	printf(_("\t-m { <keyword> [,...] | ALL }\n"
 		 "\t\tPower management statistics\n"
@@ -1170,14 +1170,15 @@ int main(int argc, char **argv)
 			which_sadc();
 		}
 
+		else if (!strcmp(argv[opt], "--human")) {
+			/* Display sizes in a human readable format */
+			flags |= S_F_UNIT;
+			opt++;
+		}
+
 		else if (!strcmp(argv[opt], "-I")) {
-			if (argv[++opt]) {
-				/* Parse -I option */
-				if (parse_sar_I_opt(argv, &opt, act)) {
-					usage(argv[0]);
-				}
-			}
-			else {
+			/* Parse -I option */
+			if (parse_sar_I_opt(argv, &opt, act)) {
 				usage(argv[0]);
 			}
 		}
