@@ -461,6 +461,9 @@ __print_funct_t xml_print_memory_stats(struct activity *a, int curr, int tab,
 		xprintf(++tab, "<memfree>%lu</memfree>",
 			smc->frmkb);
 
+		xprintf(tab, "<avail>%lu</avail>",
+			smc->availablekb);
+
 		xprintf(tab, "<memused>%lu</memused>",
 			smc->tlmkb - smc->frmkb);
 
